import { Component, OnInit, ViewChild } from '@angular/core';
import { data } from './datasource';
import { PageSettingsModel, Grid, PredicateModel, ColumnModel, FilterSettingsModel } from '@syncfusion/ej2-grids';

const initialFilteringSettings = {
  type: 'Excel',
  mode: 'Immediate',
  immediateModeDelay: 500,
  showFilterBarStatus: true
};

@Component({
  selector: 'app-grid',
  templateUrl: './grid.component.html',
  styleUrls: ['./grid.component.css']
})
export class GridComponent implements OnInit {

  public data: object[];
  public pageSettings: PageSettingsModel;
  public filterSettings: FilterSettingsModel;

  @ViewChild('grid', { static: true })
  public grid: Grid;

  constructor() { }

  ngOnInit() {

    setTimeout(() => {
      this.updateColumns();

      this.updateData();

      this.filterSettings = {
        type: 'Excel',
        mode: 'Immediate',
        immediateModeDelay: 500,
        showFilterBarStatus: true
      };

      this.updateFiltering();
    }, 100);

  }

  updateData() {
    this.data = data;
  }

  updateColumns() {
    const columns = [{
      field: 'OrderID',
      headerText: 'OrderID',
      type: 'number'
    }, {
      field: 'EmployeeID',
      headerText: 'EmployeeID',
      type: 'number'
    }, {
      field: 'ShipName',
      headerText: 'ShipName',
      type: 'string'
    }];

    this.grid.columns = columns;
  }

  actionComplete(event: any) {

    switch (event.requestType) {
      case 'refresh':
      case 'filtering': {
        const key = 'filtering_key';
        if (this.grid.filterSettings && this.grid.filterSettings.columns && this.grid.filterSettings.columns.length) {
          const config = this.grid.filterSettings.columns.reduce((cnf, column) => {
            cnf.push({
              field: column.field,
              matchCase: column.matchCase,
              operator: column.operator,
              predicate: column.predicate,
              value: column.value
            });
            return cnf;
          }, []);
          if (config.length) {
            sessionStorage.setItem(key, JSON.stringify(config));
          } else {
            sessionStorage.removeItem(key);
          }
        } else {
          sessionStorage.removeItem(key);
        }
      }
    }
  }

  updateFiltering() {

    const savedFiltering = JSON.parse(sessionStorage.getItem('filtering_key'));
    if (savedFiltering && savedFiltering.length) {
      this.filterSettings = Object.assign({}, this.filterSettings, { columns: savedFiltering });
    }
  }
}
